@@ -3,7 +3,7 @@ package Parse::RecDescent::FAQ;
 use vars qw($VERSION);
 
 
-our $VERSION = sprintf '%s', q$Revision: 3.9 $ =~ /Revision:\s+(\S+)\s+/ ;
+our $VERSION = sprintf '%s', q$Revision: 3.91 $ =~ /Revision:\s+(\S+)\s+/ ;
 
 1;
 __END__
@@ -2219,11 +2219,46 @@ Ok, so he hasn't named it yet. It's available online for free!
 You still need to know when to use C</.*/> or C</.+/> or C</[^x]*/>
 
 
-=head1 RESOURCES
+=head1 Practical Parser Examples
 
-=head2 Practical Parser Examples
+=head2 Module dependency expression parser
 
-=head3 XSH - The XML Editing Shell
+
+This code by Marc Prewitt was a response to 
+Mark Dominus' Perl 'Expert' Quiz of the Week #24 (Module dependency
+evaluation). This quiz of the week was a practical challenge to find
+code that could end up useable within Module::Build. The requirement
+was to allow for the module prerequisite to be specified using boolean
+logic, e.g.: 
+
+	requires => q[
+                 (DBD::Pg && DateTime::Format::Pg)
+                   ||
+                 (DBD::mysql && DateTime::Format::mysql)
+             ]
+
+If we need to, we can also include version specifications:
+
+             requires => q[
+                 ( DBD::Pg > 1.1 && DateTime::Format::Pg )
+                   ||
+                 ( DBD::mysql <= 1.2 && DateTime::Format::mysql )
+             ]
+
+The neat thing about the solution is that after coding it, Marc had
+PRD generate a parser that ran independantly from PRD itself.
+
+This solution, according to the judge, "... is
+probably the best solution to use if full expression parsing is
+desired for Module::Build."
+
+Marc's outline of his solution and link to full code is available
+here:
+
+	http://perl.plover.com/~alias/list.cgi?1:mss:2279:homdmfmmaelddeehiooi
+
+
+=head2 XSH - The XML Editing Shell
 
 XSH:
 
@@ -2231,7 +2266,7 @@ L<http://xsh.sourceforge.net/>
 
 uses Parse::RecDescent
 
-=head3 Parsing Symbolic Expressions / Boolean Logic
+=head2 Parsing Symbolic Expressions / Boolean Logic
 
 Says Stefan Mueller:
 
@@ -2241,13 +2276,17 @@ You can find a working example grammar for more involved
 part of the L<Math::Symbolic> distribution. 
 It should be fairly easy to modify it to work for boolean logic. 
 
-=head3 MySql to Oracle schema conversion utility
+=head2 MySql to Oracle schema conversion utility
 
 Written in Parse::RecDescent by Tim Bunce:
 
 L<http://groups.google.com/groups?q=recdescent&start=40&hl=en&scoring=d&rnum=41&selm=9km7b1%246vc%241%40FreeBSD.csie.NCTU.edu.tw>
 
 
+
+=head1 RESOURCES
+
+
 =head2 Craig's Parse::Recdescent Area
 
 Contains an article (in English)  published during the Zweiter Perl Workshop
